PetroBuffer's Code Documentation
================================
.. contents::

petrobuffer.buffers
-------------------
Module containing the buffer models

.. automodule:: petrobuffer.buffers
   :members:
   :undoc-members:
   :show-inheritance:

petrobuffer.conversions
-----------------------
Module containing the main PetroBuffer functions

.. automodule:: petrobuffer.conversions
   :members:
   :undoc-members:
   :show-inheritance:

petrobuffer.core
----------------
Module containing core data and conversions

.. automodule:: petrobuffer.core
   :members:
   :undoc-members:
   :show-inheritance:

petrobuffer.ferric
------------------
Module containing the ferric/ferrous <-> fO2 conversion models

.. automodule:: petrobuffer.ferric
   :members:
   :undoc-members:
   :show-inheritance:

